mysql.conversion.input.Input_Conversion

Package mysql :: Package conversion :: Module input :: Class Input_Conversion |
[hide private]
[frames] | no frames]

# Class Input_Conversion

source code

Known Subclasses:
  Basic_Conversion

Base class for the input conversion API.

The basic requirement is to implement the convert method which takes the values and must return a tuple of strings.

Instance Methods | [hide private]
`` | convert(self, *values) Convert Python values to strings suitable for MySQL.

Method Details | [hide private]

### convert(self, *values) | source code
Convert Python values to strings suitable for MySQL. This method takes a sequence of Python values to convert. It must return a tuple of strings suitable for MySQL, with all appropriate escaping done. Parameters: `values` - A tuple of Python values to convert. Returns: Returns a tuple of strings.